@@ -5,7 +5,6 @@ use strict;
 use Carp;
 
 use Geo::Coder::Many::Generic;
-use Geo::Coder::Many::Util;
 use base 'Geo::Coder::Many::Generic';
 
 =head1 NAME
@@ -14,14 +13,11 @@ Geo::Coder::Many::PlaceFinder - Yahoo PlaceFinder plugin for Geo::Coder::Many
 
 =head1 VERSION
 
-Version 0.03
+Version 0.02
 
 =cut
 
-our $VERSION = '0.03';
-
-# Requires Geo::Coder::PlaceFinder 0.02 or above
-sub _MIN_MODULE_VERSION { return '0.02'; }
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -31,9 +27,10 @@ Use as follows:
 
     use Geo::Coder::Many;
     use Geo::Coder::PlaceFinder;
+    use Geo::Coder::Many::PlaceFinder;
     
     my $options = { };
-    my $geocoder_many = Geo::Coder::Many->new( $options );
+    my $geocoder_multi = Geo::Coder::Many->new( $options );
     my $place_finder = Geo::Coder::PlaceFinder->new( appid => 'YOUR_APP_ID' );
     
     my $place_finder_options = {
@@ -41,13 +38,9 @@ Use as follows:
         daily_limit => 50000,
     };
     
-    $geocoder_many->add_geocoder( $place_finder_options );
+    $geocoder_multi->add_geocoder( $place_finder_options );
     
-    my $location = $geocoder_many->geocode( 
-        {
-            location => '82 Clerkenwell Road, London, EC1M 5RF'
-        }
-    );
+    my $location = $geocoder_multi->geocode( { location => '82 Clerkenwell Road, London, EC1M 5RF' } );
 
 =head1 USAGE POLICY
 
@@ -84,35 +77,21 @@ sub geocode {
         @address_lines = grep {!/^\s*$/x} @address_lines;
         my $address = (join ', ', @address_lines);
 
-	my $precision = 0;
-	if (defined($raw_reply->{boundingbox})){
-	    
-	    my $box = $raw_reply->{boundingbox};
-	    # lng and lat in decimal degree format            
-	    
-	    $precision = 
-		Geo::Coder::Many::Util::determine_precision_from_bbox({
-		    'lon1' => $box->{west},
-		    'lat1' => $box->{south},
-		    'lon2' => $box->{east},
-		    'lat2' => $box->{north},
-                });
-
-	} 
         my $tmp = {
               address     => $address,
               country     => $raw_reply->{country},
               longitude   => $raw_reply->{longitude},
               latitude    => $raw_reply->{latitude},
-              precision   => $precision,
+              precision   => $raw_reply->{quality} / 100,
         };
 
         $response->add_response( $tmp, $self->get_name() );
-    }
+    };
 
     $response->set_response_code($http_response->code());
-    return $response;
-}
+
+    return( $response );
+};
 
 =head2 get_name
 
@@ -120,6 +99,66 @@ Returns the name of the geocoder type - used by Geo::Coder::Many
 
 =cut
 
-sub get_name { my $self = shift; return 'place_finder ' . $self->{GeoCoder}->VERSION; };
+sub get_name { return 'place_finder' };
+
+=head1 AUTHOR
+
+Dan Horgan, C<< <cpan at lokku.com> >>
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-geo-coder-multiple-placefinder at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Geo-Coder-Many-PlaceFinder>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Geo::Coder::Many::PlaceFinder
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Geo-Coder-Many-PlaceFinder>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Geo-Coder-Many-PlaceFinder>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Geo-Coder-Many-PlaceFinder>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Geo-Coder-Many-PlaceFinder/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+This module is based on the Geo::Coder::Many::* modules provided with Geo::Coder::Many.
+It is, of course, useless without Geo::Coder::Many and Geo::Coder::PlaceFinder.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2010 Lokku Ltd.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
 
 1; # End of Geo::Coder::Many::PlaceFinder
